@@ -3,12 +3,12 @@ package Test::Run::CmdLine::Plugin::StupidRunTests;
 use strict;
 use warnings;
 
-use MRO::Compat;
+use Moose;
 
-sub _init
+sub BUILD
 {
     my $self = shift;
-    $self->next::method(@_);
+
     $self->add_to_backend_plugins("StupidRunTests");
 }
 
