@@ -3,14 +3,12 @@ package Test::Run::CmdLine::Plugin::Super;
 use strict;
 use warnings;
 
-use MRO::Compat;
+use Moose;
 
-use mro "dfs";
-
-sub _init
+sub BUILD
 {
     my $self = shift;
-    $self->next::method(@_);
+
     $self->add_to_backend_plugins("Super");
 }
 
